[Lldb-commits] [PATCH] D10906: Fix type signature for CMIUtilString::IsAllValidAlphaAndNumeric.This should take a "const char*" not a "char &".

Bruce Mitchener bruce.mitchener at gmail.com
Thu Jul 2 22:24:19 PDT 2015


brucem updated this revision to Diff 28993.
brucem added a comment.

Update per review comments.

Updating D10906: Fix type signature for CMIUtilString::IsAllValidAlphaAndNumeric.
=================================================================================

This should take a "const char*" not a "char &".


http://reviews.llvm.org/D10906

Files:
  tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
  tools/lldb-mi/MIUtilString.cpp
  tools/lldb-mi/MIUtilString.h

Index: tools/lldb-mi/MIUtilString.h
===================================================================
--- tools/lldb-mi/MIUtilString.h
+++ tools/lldb-mi/MIUtilString.h
@@ -35,7 +35,7 @@
     static CMIUtilString Format(const CMIUtilString vFormating, ...);
     static CMIUtilString FormatBinary(const MIuint64 vnDecimal);
     static CMIUtilString FormatValist(const CMIUtilString &vrFormating, va_list vArgs);
-    static bool IsAllValidAlphaAndNumeric(const MIchar &vrText);
+    static bool IsAllValidAlphaAndNumeric(const MIchar *vpText);
     static bool Compare(const CMIUtilString &vrLhs, const CMIUtilString &vrRhs);
     static CMIUtilString ConvertToPrintableASCII(const char vChar);
     static CMIUtilString ConvertToPrintableASCII(const char16_t vChar16);
Index: tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
===================================================================
--- tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
+++ tools/lldb-mi/MICmnLLDBDebugSessionInfo.cpp
@@ -383,7 +383,7 @@
     const MIchar *pThreadName = rThread.GetName();
     const MIuint len = (pThreadName != nullptr) ? CMIUtilString(pThreadName).length() : 0;
     const bool bHaveName = ((pThreadName != nullptr) && (len > 0) && (len < 32) &&
-                            CMIUtilString::IsAllValidAlphaAndNumeric(*pThreadName)); // 32 is arbitary number
+                            CMIUtilString::IsAllValidAlphaAndNumeric(pThreadName)); // 32 is arbitary number
     const MIchar *pThrdFmt = bHaveName ? "%s" : "Thread %d";
     CMIUtilString strThread;
     if (bHaveName)


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D10906.28993.patch
Type: text/x-patch
Size: 2694 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/lldb-commits/attachments/20150703/0414dd99/attachment.bin>


More information about the lldb-commits mailing list
Index: tools/lldb-mi/MIUtilString.cpp
===================================================================
--- tools/lldb-mi/MIUtilString.cpp
+++ tools/lldb-mi/MIUtilString.cpp
@@ -475,21 +475,20 @@
 // Details: Determine if the text is all valid alpha numeric characters. Letters can be
 //          either upper or lower case.
 // Type:    Static method.
 // Args:    vrText  - (R) The text data to examine.
 // Return:  bool - True = yes all alpha, false = one or more chars is non alpha.
 // Throws:  None.
 //--
 bool
-CMIUtilString::IsAllValidAlphaAndNumeric(const MIchar &vrText)
+CMIUtilString::IsAllValidAlphaAndNumeric(const MIchar *vpText)
 {
-    const MIuint len = ::strlen(&vrText);
+    const MIuint len = ::strlen(vpText);
     if (len == 0)
         return false;
 
-    MIchar *pPtr = const_cast<MIchar *>(&vrText);
-    for (MIuint i = 0; i < len; i++, pPtr++)
+    for (MIuint i = 0; i < len; i++, vpText++)
     {
-        const MIchar c = *pPtr;
+        const MIchar c = *vpText;
         if (::isalnum((int)c) == 0)
             return false;
     }
@@ -475,21 +475,20 @@
 //          either upper or lower case.
 // Type:    Static method.
-// Args:    vrText  - (R) The text data to examine.
+// Args:    vpText  - (R) The text data to examine.
 // Return:  bool - True = yes all alpha, false = one or more chars is non alpha.
 // Throws:  None.